==> vala-0.1.0.tar.bz2: vala-0.1.0/vala/valaifstatement.h <==
/* valaifstatement.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALAIFSTATEMENT_H__
#define __VALAIFSTATEMENT_H__
typedef struct _ValaIfStatementPrivate ValaIfStatementPrivate;

#include <glib.h>
#include <glib-object.h>
#include <vala/valastatement.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_IF_STATEMENT (vala_if_statement_get_type ())
#define VALA_IF_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_IF_STATEMENT, ValaIfStatement))
#define VALA_IF_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_IF_STATEMENT, ValaIfStatementClass))
#define VALA_IS_IF_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_IF_STATEMENT))
#define VALA_IS_IF_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_IF_STATEMENT))
#define VALA_IF_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_IF_STATEMENT, ValaIfStatementClass))


/**
 * Represents an if selection statement in the source code.
 */
struct _ValaIfStatement {
	ValaStatement parent;
	ValaIfStatementPrivate * priv;
};
struct _ValaIfStatementClass {
	ValaStatementClass parent;
};

ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_stmt, ValaBlock* false_stmt, ValaSourceReference* source);
ValaExpression* vala_if_statement_get_condition (ValaIfStatement* self);
void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* value);
ValaBlock* vala_if_statement_get_true_statement (ValaIfStatement* self);
void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* value);
ValaBlock* vala_if_statement_get_false_statement (ValaIfStatement* self);
void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* value);
GType vala_if_statement_get_type ();

G_END_DECLS

#endif

==> vala-0.3.2.tar.bz2: vala-0.3.2/vala/valaifstatement.h <==
/* valaifstatement.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALAIFSTATEMENT_H__
#define __VALA_VALAIFSTATEMENT_H__

#include <glib.h>
#include <glib-object.h>
#include <vala/valacodenode.h>
#include <vala/valastatement.h>

G_BEGIN_DECLS


#define VALA_TYPE_IF_STATEMENT (vala_if_statement_get_type ())
#define VALA_IF_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_IF_STATEMENT, ValaIfStatement))
#define VALA_IF_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_IF_STATEMENT, ValaIfStatementClass))
#define VALA_IS_IF_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_IF_STATEMENT))
#define VALA_IS_IF_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_IF_STATEMENT))
#define VALA_IF_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_IF_STATEMENT, ValaIfStatementClass))

typedef struct _ValaIfStatementPrivate ValaIfStatementPrivate;

/**
 * Represents an if selection statement in the source code.
 */
struct _ValaIfStatement {
	ValaCodeNode parent_instance;
	ValaIfStatementPrivate * priv;
};

struct _ValaIfStatementClass {
	ValaCodeNodeClass parent_class;
};


ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_stmt, ValaBlock* false_stmt, ValaSourceReference* source);
ValaExpression* vala_if_statement_get_condition (ValaIfStatement* self);
void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* value);
ValaBlock* vala_if_statement_get_true_statement (ValaIfStatement* self);
void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* value);
ValaBlock* vala_if_statement_get_false_statement (ValaIfStatement* self);
void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* value);
GType vala_if_statement_get_type (void);


G_END_DECLS

#endif
